from distutils.core import setup

setup(
       name          = 'menlol',
       version       = '1.0.4',
       py_modules    = ['menlol'],
       author        = 'holin',
       author_email  = 'holin@holin.net',
       url           = 'http://www.holin.net',
       description   = 'print a list',

        )

